==> actel_1.0.0.tar.gz: actel/tests/testthat/aux_breakMatricesByArray.R <==
aux_breakMatricesByArray <- list()
aux_breakMatricesByArray$River1$A.RS1 <- read.csv(text = ',FakeStart,River1,AnyPeer
4451,1,1,1
4453,1,1,1
4454,1,1,1
4456,1,1,1
4457,1,1,1
4459,1,1,1
4462,1,1,1
4465,1,1,1
4466,1,1,1
4469,1,1,1
4470,1,1,1
4472,1,1,1
4473,1,1,1
4474,1,1,1
4477,1,1,1
4480,1,1,1
4481,1,1,1
4484,1,1,1
4486,1,1,1
4488,1,1,1
4490,1,1,1
4492,1,1,1
4494,1,1,1
4496,1,1,1
4498,1,1,1
4499,1,1,1
4450,1,0,0
4478,1,0,0
4452,1,0,0
4464,1,0,0', row.names = 1)
aux_breakMatricesByArray$River1$B.RS1 <- read.csv(text = ',FakeStart,River1,AnyPeer
4502,1,1,1
4503,1,1,1
4505,1,1,1
4508,1,1,1
4509,1,1,1
4510,1,1,1
4511,1,1,1
4512,1,1,1
4513,1,1,1
4514,1,1,1
4515,1,1,1
4516,1,1,1
4517,1,1,1
4518,1,1,1
4519,1,1,1
4521,1,1,1
4522,1,1,1
4524,1,1,1
4526,1,1,1
4529,1,1,1
4532,1,1,1
4534,1,1,1
4536,1,1,1
4541,1,1,1
4543,1,1,1
4545,1,1,1
4547,1,1,1
4549,1,1,1
4527,1,0,0
4520,1,0,0', row.names = 1)
aux_breakMatricesByArray$River2$A.RS1 <- read.csv(text = ',FakeStart,River2,AnyPeer
4451,1,1,1
4453,1,1,1
4454,1,1,1
4456,1,1,1
4457,1,1,1
4459,1,1,1
4462,1,1,1
4465,1,1,1
4466,1,1,1
4469,1,1,1
4470,1,1,1
4472,1,1,1
4473,1,1,1
4474,1,1,1
4477,1,1,1
4480,1,1,1
4481,1,1,1
4484,1,1,1
4486,1,1,1
4488,1,1,1
4490,1,1,1
4492,1,1,1
4494,1,1,1
4496,1,1,1
4498,1,1,1
4499,1,1,1
4450,1,0,0
4478,1,0,0
4452,1,0,0
4464,1,0,0', row.names = 1)
aux_breakMatricesByArray$River2$B.RS1 <- read.csv(text = ',FakeStart,River2,AnyPeer
4502,1,1,1
4503,1,1,1
4505,1,1,1
4508,1,1,1
4509,1,1,1
4510,1,1,1
4511,1,1,1
4512,1,1,1
4513,1,1,1
4514,1,1,1
4515,1,1,1
4516,1,1,1
4517,1,1,1
4518,1,1,1
4519,1,1,1
4521,1,1,1
4522,1,1,1
4524,1,1,1
4526,1,1,1
4529,1,1,1
4532,1,1,1
4534,1,1,1
4536,1,1,1
4541,1,1,1
4543,1,1,1
4545,1,1,1
4547,1,1,1
4549,1,1,1
4527,1,0,0
4520,1,0,0', row.names = 1)
aux_breakMatricesByArray$River3$A.RS1 <- read.csv(text = ',FakeStart,River3,AnyPeer
4451,1,1,1
4453,1,1,1
4454,1,1,1
4456,1,1,1
4457,1,1,1
4459,1,1,1
4462,1,1,1
4465,1,1,1
4466,1,1,1
4469,1,1,1
4470,1,1,1
4472,1,1,1
4473,1,1,1
4474,1,1,1
4477,1,1,1
4480,1,1,1
4481,1,1,1
4484,1,1,1
4486,1,1,1
4488,1,1,1
4490,1,1,1
4492,1,0,1
4494,1,1,1
4496,1,1,1
4498,1,1,1
4499,1,1,1
4450,1,0,0
4478,1,0,0
4452,1,0,0
4464,1,0,0', row.names = 1)
aux_breakMatricesByArray$River3$B.RS1 <- read.csv(text = ',FakeStart,River3,AnyPeer
4502,1,1,1
4503,1,1,1
4505,1,1,1
4508,1,1,1
4509,1,1,1
4510,1,1,1
4511,1,1,1
4512,1,1,1
4513,1,1,1
4514,1,1,1
4515,1,1,1
4516,1,1,1
4517,1,1,1
4518,1,1,1
4519,1,1,1
4521,1,1,1
4522,1,1,0
4524,1,1,1
4526,1,1,1
4529,1,1,1
4532,1,1,1
4534,1,1,0
4536,1,1,1
4541,1,1,1
4543,1,1,1
4545,1,0,1
4547,1,1,1
4549,1,1,1
4527,1,0,0
4520,1,0,0', row.names = 1)
aux_breakMatricesByArray$River4$A.RS1 <- read.csv(text = ',FakeStart,River4,AnyPeer
4451,1,1,1
4453,1,1,1
4454,1,1,1
4456,1,1,1
4457,1,1,1
4459,1,1,1
4462,1,1,1
4465,1,1,1
4466,1,1,1
4469,1,1,1
4470,1,1,1
4472,1,1,1
4473,1,1,1
4474,1,1,1
4477,1,1,1
4480,1,1,1
4481,1,1,1
4484,1,1,1
4486,1,1,1
4488,1,1,1
4490,1,1,1
4492,1,1,1
4494,1,1,1
4496,1,1,1
4498,1,1,1
4499,1,1,1
4450,1,0,0
4478,1,0,0
4452,1,0,0
4464,1,0,0', row.names = 1)
aux_breakMatricesByArray$River4$B.RS1 <- read.csv(text = ',FakeStart,River4,AnyPeer
4502,1,1,1
4503,1,1,1
4505,1,1,1
4508,1,1,1
4509,1,1,1
4510,1,1,1
4511,1,1,1
4512,1,1,1
4513,1,1,1
4514,1,1,1
4515,1,1,1
4516,1,1,1
4517,1,1,1
4518,1,1,1
4519,1,1,1
4521,1,1,1
4522,1,0,0
4524,1,1,1
4526,1,1,1
4529,1,1,1
4532,1,1,1
4534,1,0,0
4536,1,1,1
4541,1,1,1
4543,1,1,1
4545,1,1,1
4547,1,1,1
4549,1,1,1
4527,1,0,0
4520,1,0,0', row.names = 1)
aux_breakMatricesByArray$River5$A.RS1 <- read.csv(text = ',FakeStart,River5,AnyPeer
4451,1,1,1
4453,1,1,1
4454,1,1,1
4456,1,1,1
4457,1,1,1
4459,1,1,1
4462,1,1,1
4465,1,1,1
4466,1,1,1
4469,1,1,1
4470,1,1,1
4472,1,1,1
4473,1,1,1
4474,1,1,1
4477,1,1,1
4480,1,1,1
4481,1,1,1
4484,1,1,1
4486,1,1,1
4488,1,1,1
4490,1,1,1
4492,1,1,1
4494,1,1,1
4496,1,1,1
4498,1,1,1
4499,1,1,1
4450,1,0,0
4478,1,0,0
4452,1,0,0
4464,1,0,0', row.names = 1)
aux_breakMatricesByArray$River5$B.RS1 <- read.csv(text = ',FakeStart,River5,AnyPeer
4502,1,1,1
4503,1,1,1
4505,1,1,1
4508,1,1,1
4509,1,1,1
4510,1,1,1
4511,1,1,1
4512,1,1,1
4513,1,1,1
4514,1,1,1
4515,1,1,1
4516,1,1,1
4517,1,1,1
4518,1,1,1
4519,1,1,1
4521,1,1,1
4522,1,0,0
4524,1,1,1
4526,1,1,1
4529,1,1,1
4532,1,1,1
4534,1,0,0
4536,1,1,1
4541,1,1,1
4543,1,1,1
4545,1,1,1
4547,1,1,1
4549,1,1,1
4527,1,0,0
4520,1,0,0', row.names = 1)
aux_breakMatricesByArray$River6$A.RS1 <- read.csv(text = ',FakeStart,River6,AnyPeer
4451,1,1,1
4453,1,1,1
4454,1,1,1
4456,1,1,1
4457,1,1,1
4459,1,1,1
4462,1,1,1
4465,1,1,1
4466,1,1,1
4469,1,1,1
4470,1,1,1
4472,1,1,1
4473,1,1,1
4474,1,1,1
4477,1,1,1
4480,1,1,1
4481,1,1,1
4484,1,1,1
4486,1,1,1
4488,1,1,1
4490,1,1,1
4492,1,1,1
4494,1,1,1
4496,1,1,1
4498,1,1,1
4499,1,1,1
4450,1,0,0
4478,1,0,0
4452,1,0,0
4464,1,0,0', row.names = 1)
aux_breakMatricesByArray$River6$B.RS1 <- read.csv(text = ',FakeStart,River6,AnyPeer
4502,1,1,1
4503,1,1,1
4505,1,1,1
4508,1,1,1
4509,1,1,1
4510,1,1,1
4511,1,1,1
4512,1,1,1
4513,1,1,1
4514,1,1,1
4515,1,1,1
4516,1,1,1
4517,1,1,1
4518,1,1,0
4519,1,1,1
4521,1,1,1
4522,1,0,0
4524,1,1,1
4526,1,1,1
4529,1,1,1
4532,1,1,1
4534,1,0,0
4536,1,1,0
4541,1,1,1
4543,1,1,1
4545,1,1,1
4547,1,1,1
4549,1,1,1
4527,1,0,0
4520,1,0,0', row.names = 1)
aux_breakMatricesByArray$Fjord1$A.RS1 <- read.csv(text = ',FakeStart,Fjord1,AnyPeer
4451,1,1,1
4453,1,1,1
4454,1,1,1
4456,1,1,1
4457,1,1,1
4459,1,1,1
4462,1,1,1
4465,1,1,1
4466,1,1,1
4469,1,1,1
4470,1,1,1
4472,1,1,0
4473,1,1,1
4474,1,1,1
4477,1,1,1
4480,1,1,1
4481,1,1,1
4484,1,1,1
4486,1,1,1
4488,1,1,1
4490,1,1,1
4492,1,1,1
4494,1,1,1
4496,1,1,1
4498,1,1,1
4499,1,1,1
4450,1,0,0
4478,1,0,0
4452,1,0,0
4464,1,0,0', row.names = 1)
aux_breakMatricesByArray$Fjord1$B.RS1 <- read.csv(text = ',FakeStart,Fjord1,AnyPeer
4502,1,1,1
4503,1,1,1
4505,1,1,0
4508,1,1,1
4509,1,1,1
4510,1,1,1
4511,1,0,1
4512,1,1,1
4513,1,1,1
4514,1,1,1
4515,1,1,0
4516,1,1,1
4517,1,1,1
4518,1,0,0
4519,1,1,1
4521,1,1,0
4522,1,0,0
4524,1,1,1
4526,1,1,1
4529,1,1,0
4532,1,1,1
4534,1,0,0
4536,1,0,0
4541,1,1,1
4543,1,1,0
4545,1,1,1
4547,1,1,1
4549,1,1,1
4527,1,0,0
4520,1,0,0', row.names = 1)
aux_breakMatricesByArray$Fjord2$A.RS1 <- read.csv(text = ',FakeStart,Fjord2,AnyPeer
4451,1,1,0
4453,1,1,1
4454,1,1,1
4456,1,1,1
4457,1,1,0
4459,1,1,1
4462,1,1,1
4465,1,1,1
4466,1,1,0
4469,1,1,1
4470,1,1,0
4472,1,0,0
4473,1,1,1
4474,1,1,1
4477,1,1,1
4480,1,1,1
4481,1,1,1
4484,1,1,1
4486,1,1,0
4488,1,1,1
4490,1,1,1
4492,1,1,0
4494,1,1,1
4496,1,1,1
4498,1,1,1
4499,1,1,1
4450,1,0,0
4478,1,0,0
4452,1,0,0
4464,1,0,0', row.names = 1)
aux_breakMatricesByArray$Fjord2$B.RS1 <- read.csv(text = ',FakeStart,Fjord2,AnyPeer
4502,1,1,1
4503,1,1,1
4505,1,0,0
4508,1,1,1
4509,1,1,0
4510,1,1,1
4511,1,1,1
4512,1,1,0
4513,1,1,1
4514,1,1,1
4515,1,0,0
4516,1,1,1
4517,1,1,1
4518,1,0,0
4519,1,1,1
4521,1,0,0
4522,1,0,0
4524,1,1,0
4526,1,1,1
4529,1,0,0
4532,1,1,1
4534,1,0,0
4536,1,0,0
4541,1,1,1
4543,1,0,0
4545,1,1,1
4547,1,1,1
4549,1,1,0
4527,1,0,0
4520,1,0,0', row.names = 1)

==> actel_1.1.1.tar.gz: actel/tests/testthat/aux_breakMatricesByArray.R <==
aux_breakMatricesByArray <- list()
aux_breakMatricesByArray$A1$A.RS1<- read.csv(text = ',FakeStart,A1,AnyPeer
4451,1,1,1
4453,1,1,1
4454,1,1,1
4456,1,1,1
4457,1,1,1
4459,1,1,1
4462,1,1,1
4465,1,1,1
4466,1,1,1
4469,1,1,1
4470,1,1,1
4472,1,1,1
4473,1,1,1
4474,1,1,1
4477,1,1,1
4480,1,1,1
4481,1,1,1
4484,1,1,1
4486,1,1,1
4488,1,1,1
4490,1,1,1
4492,1,1,1
4494,1,1,1
4496,1,1,1
4498,1,1,1
4499,1,1,1
4450,1,0,0
4478,1,0,0
4452,1,0,0
4464,1,0,0', row.names = 1)
aux_breakMatricesByArray$A1$B.RS1<- read.csv(text = ',FakeStart,A1,AnyPeer
4502,1,1,1
4503,1,1,1
4505,1,1,1
4508,1,1,1
4509,1,1,1
4510,1,1,1
4511,1,1,1
4512,1,1,1
4513,1,1,1
4514,1,1,1
4515,1,1,1
4516,1,1,1
4517,1,1,1
4518,1,1,1
4519,1,1,1
4521,1,1,1
4522,1,1,1
4524,1,1,1
4526,1,1,1
4529,1,1,1
4532,1,1,1
4534,1,1,1
4536,1,1,1
4541,1,1,1
4543,1,1,1
4545,1,1,1
4547,1,1,1
4549,1,1,1
4527,1,0,0
4520,1,0,0', row.names = 1)
aux_breakMatricesByArray$A2$A.RS1<- read.csv(text = ',FakeStart,A2,AnyPeer
4451,1,1,1
4453,1,1,1
4454,1,1,1
4456,1,1,1
4457,1,1,1
4459,1,1,1
4462,1,1,1
4465,1,1,1
4466,1,1,1
4469,1,1,1
4470,1,1,1
4472,1,1,1
4473,1,1,1
4474,1,1,1
4477,1,1,1
4480,1,1,1
4481,1,1,1
4484,1,1,1
4486,1,1,1
4488,1,1,1
4490,1,1,1
4492,1,1,1
4494,1,1,1
4496,1,1,1
4498,1,1,1
4499,1,1,1
4450,1,0,0
4478,1,0,0
4452,1,0,0
4464,1,0,0', row.names = 1)
aux_breakMatricesByArray$A2$B.RS1<- read.csv(text = ',FakeStart,A2,AnyPeer
4502,1,1,1
4503,1,1,1
4505,1,1,1
4508,1,1,1
4509,1,1,1
4510,1,1,1
4511,1,1,1
4512,1,1,1
4513,1,1,1
4514,1,1,1
4515,1,1,1
4516,1,1,1
4517,1,1,1
4518,1,1,1
4519,1,1,1
4521,1,1,1
4522,1,1,1
4524,1,1,1
4526,1,1,1
4529,1,1,1
4532,1,1,1
4534,1,1,1
4536,1,1,1
4541,1,1,1
4543,1,1,1
4545,1,1,1
4547,1,1,1
4549,1,1,1
4527,1,0,0
4520,1,0,0', row.names = 1)
